Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(68)

Unified Diff: chrome/browser/ui/extensions/application_launch.h

Issue 10949023: Add switch to provide app window size on startup (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: remove hack Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/extensions/application_launch.h
diff --git a/chrome/browser/ui/extensions/application_launch.h b/chrome/browser/ui/extensions/application_launch.h
index ed7377dffd74f39dd1e739cf7b24cc6953bbbb88..629df468af264a2214c26ef0b6b0d629c4388cb0 100644
--- a/chrome/browser/ui/extensions/application_launch.h
+++ b/chrome/browser/ui/extensions/application_launch.h
@@ -22,6 +22,10 @@ namespace extensions {
class Extension;
}
+namespace gfx {
+class Rect;
+}
+
namespace application_launch {
struct LaunchParams {
@@ -57,14 +61,14 @@ struct LaunchParams {
// Open the application in a way specified by |params|.
content::WebContents* OpenApplication(const LaunchParams& params);
// Open |url| in an app shortcut window. If |update_shortcut| is true,
// update the name, description, and favicon of the shortcut.
// There are two kinds of app shortcuts: Shortcuts to a URL,
// and shortcuts that open an installed application. This function
// is used to open the former. To open the latter, use
// application_launch::OpenApplication().
content::WebContents* OpenAppShortcutWindow(Profile* profile,
- const GURL& url);
+ const GURL& url,
+ const gfx::Rect& override_bounds);
} // namespace application_launch
« no previous file with comments | « chrome/browser/chromeos/login/existing_user_controller.cc ('k') | chrome/browser/ui/extensions/application_launch.cc » ('j') | no next file with comments »
@@ -57,14 +61,14 @@ struct LaunchParams {
// Open the application in a way specified by |params|.
content::WebContents* OpenApplication(const LaunchParams& params);
-// Open |url| in an app shortcut window. If |update_shortcut| is true,
-// update the name, description, and favicon of the shortcut.
+// Open |url| in an app shortcut window. |override_bounds| param is optional.
// There are two kinds of app shortcuts: Shortcuts to a URL,
// and shortcuts that open an installed application. This function

Powered by Google App Engine
This is Rietveld 408576698